<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:template match="grid">
		<xsl:param name="parent" />
		<xsl:param name="fromView" />
		<xsl:param name="view_configuration_id" />
		<xsl:param name="is_version_rm_support" />
		<xsl:param name="profile" />
		<xsl:param name="level" select="count(./ancestor::*)-count(//view/ancestor::*)" />
		<xsl:param name="indentation">
			<xsl:call-template name="dup">
				<xsl:with-param name="input" select="$indent" />
				<xsl:with-param name="count" select="$level" />
			</xsl:call-template>
		</xsl:param>
		<xsl:param name="indentation1">
			<xsl:call-template name="dup">
				<xsl:with-param name="input" select="$indent" />
				<xsl:with-param name="count" select="$level+1" />
			</xsl:call-template>
		</xsl:param>

		<xsl:choose>
			<xsl:when test="$fromView = 'true'">
				<xsl:value-of select="concat($indentation, 'if (!vc->', @id, ') {', $newline)" />
				<xsl:value-of select="concat($indentation1, 'vc->', @id, '= elm_grid_add(parent);', $newline)" />
				<xsl:value-of select="concat($indentation1, 'vc->root_container = vc->', @id, ';', $newline)" />
				<xsl:value-of select="concat($indentation,'}', $newline)" />
			</xsl:when>
			<xsl:otherwise>
				<xsl:if test="string-length($fromView) = 0">
					<xsl:value-of select="concat($indentation, 'if (!vc->', @id, ') {', $newline)" />
					<xsl:value-of select="concat($indentation1, 'vc->', @id, '= elm_grid_add(vc->', $parent,');', $newline)" />
					<xsl:value-of select="concat($indentation,'}', $newline)" />
				</xsl:if>

				<xsl:value-of select="concat($indentation, 'if(vc->', @id, ') {', $newline)" />
				<xsl:value-of select="concat($indentation1, 'elm_grid_clear(vc->', @id, ', EINA_FALSE);', $newline)" />

				<xsl:call-template name="size_hint_align_set">
					<xsl:with-param name="align_h" select="@align_h" />
					<xsl:with-param name="align_v" select="@align_v" />
					<xsl:with-param name="indentation" select="$indentation1" />
					<xsl:with-param name="id" select="@id" />
				</xsl:call-template>

				<xsl:call-template name="size_hint_weight_set">
					<xsl:with-param name="weight_h" select="@weight_h" />
					<xsl:with-param name="weight_v" select="@weight_v" />
					<xsl:with-param name="indentation" select="$indentation1" />
					<xsl:with-param name="id" select="@id" />
				</xsl:call-template>

				<xsl:choose>
					<xsl:when test="string-length(@vsize_w) != 0 and string-length(@vsize_h) != 0">
						<xsl:value-of select="concat($indentation1, 'elm_grid_size_set(vc->', @id, ', ', @vsize_w, ', ', @vsize_h, ');', $newline)" />
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="concat($indentation1, 'elm_grid_size_set(vc->', @id, ', ', '480', ', ', '800', ');', $newline)" />
					</xsl:otherwise>
				</xsl:choose>

				<xsl:apply-templates select="*">
					<xsl:with-param name="parent" select="@id" />
					<xsl:with-param name="view_configuration_id" select="$view_configuration_id" />
					<xsl:with-param name="is_version_rm_support" select="$is_version_rm_support" />
					<xsl:with-param name="profile" select="$profile" />
				</xsl:apply-templates>

				<xsl:apply-templates mode="grid_pack" select="*">
					<xsl:with-param name="parent" select="@id" />
					<xsl:with-param name="view_configuration_id" select="$view_configuration_id" />
				</xsl:apply-templates>

				<xsl:if test="@disable = 'true'">
					<xsl:value-of select="concat($indentation1, 'elm_object_disabled_set(vc->', @id, ', EINA_TRUE);', $newline)" />
				</xsl:if>
				<xsl:apply-templates mode="visible" select="current()">
					<xsl:with-param name="parent" select="@id" />
					<xsl:with-param name="view_configuration_id" select="$view_configuration_id" />
				</xsl:apply-templates>
				<xsl:value-of select="concat($indentation,'}', $newline)" />
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template match="*" mode="grid_pack">
		<xsl:param name="parent" />
		<xsl:param name="view_configuration_id" />
		<xsl:param name="level" select="count(./ancestor::*)-count(//view/ancestor::*)" />
		<xsl:variable name="widget_id" select="@id" />
		<xsl:param name="indentation">
			<xsl:call-template name="dup">
				<xsl:with-param name="input" select="$indent" />
				<xsl:with-param name="count" select="$level" />
			</xsl:call-template>
		</xsl:param>
		<xsl:choose>
			<xsl:when test="name()='variation'" />
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="count(./variation[@config_ref=$view_configuration_id]) > 0">
						<xsl:for-each select="./variation[@config_ref=$view_configuration_id]">
							<xsl:value-of
								select="concat($indentation, 'elm_grid_pack(vc->', $parent, ', vc->', $widget_id, ', ', @pack_x, ', ', @pack_y, ', ', @pack_w, ', ', @pack_h, ');', 					'&#xD;'
										)" />
						</xsl:for-each>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of
							select="concat($indentation, 'elm_grid_pack(vc->', $parent, ', vc->', $widget_id, ', ', @pack_x, ', ', @pack_y, ', ', @pack_w, ', ', @pack_h, ');', 					'&#xD;'
								)" />
					</xsl:otherwise>
				</xsl:choose>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
</xsl:stylesheet>
